@@ -5,9 +5,8 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '0.92'; # TRIAL
+our $VERSION = '1.031'; # TRIAL
 
-use Carp ();
 use Log::Any::Manager;
 use Log::Any::Adapter::Util qw(
   require_dynamic
@@ -54,8 +53,10 @@ sub _export_to_caller {
         }
     }
 
-    Carp::croak("Argument list not balanced: @params")
-      unless @params % 2 == 0;
+    unless ( @params % 2 == 0 ) {
+        require Carp;
+        Carp::croak("Argument list not balanced: @params");
+    }
 
     # get logger if one was requested
     if ($saw_log_param) {
@@ -119,7 +120,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 0.92
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -247,7 +248,7 @@ on messages to the L<Log::Any::Adapter> handling its category.
 
 =head2 Logging
 
-To log a message, use any of the log levels or aliases. e.g.
+To log a message, pass a single string to any of the log levels or aliases. e.g.
 
     $log->error("this is an error");
     $log->warn("this is a warning");
