@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter;
 
 # ABSTRACT: Tell Log::Any where to send its logs
-our $VERSION = '0.92'; # TRIAL
+our $VERSION = '1.031'; # TRIAL
 
 use Log::Any;
 
@@ -38,7 +38,7 @@ Log::Any::Adapter - Tell Log::Any where to send its logs
 
 =head1 VERSION
 
-version 0.92
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -85,8 +85,8 @@ adapter class for it. Typically this is named Log::Any::Adapter::I<something>.
 
 =head2 Adapters in this distribution
 
-Three basic adapters come with this distribution -- L<File>, L<Stdout> and
-L<Stderr>:
+Three basic adapters come with this distribution -- L<Log::Any::Adapter::File>,
+L<Log::Any::Adapter::Stdout> and L<Log::Any::Adapter::Stderr>:
 
     use Log::Any::Adapter ('File', '/path/to/file.log');
     use Log::Any::Adapter ('Stdout');
