@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::Util;
 
 # ABSTRACT: Common utility functions for Log::Any
-our $VERSION = '0.92'; # TRIAL
+our $VERSION = '1.031'; # TRIAL
 
 use Data::Dumper;
 use base qw(Exporter);
@@ -37,6 +37,7 @@ our @EXPORT_OK = qw(
   logging_and_detection_methods
   logging_methods
   make_method
+  numeric_level
   read_file
   require_dynamic
 );
@@ -207,6 +208,11 @@ sub cmp_deeply {
     $tb->is_eq( dump_one_line($ref1), dump_one_line($ref2), $name );
 }
 
+# 0.XX version loaded Log::Any and some adapters relied on this happening
+# behind the scenes.  Since Log::Any now uses this module, we load Log::Any
+# via require after compilation to mitigate circularity.
+require Log::Any;
+
 1;
 
 
@@ -224,7 +230,7 @@ Log::Any::Adapter::Util - Common utility functions for Log::Any
 
 =head1 VERSION
 
-version 0.92
+version 1.031
 
 =head1 DESCRIPTION
 
