@@ -4,10 +4,7 @@ use warnings;
 
 package Log::Any::Manager;
 
-our $VERSION = '0.92'; # TRIAL
-
-use Carp qw(croak);
-use Log::Any::Adapter::Util qw(require_dynamic);
+our $VERSION = '1.031'; # TRIAL
 
 sub new {
     my $class = shift;
@@ -52,7 +49,7 @@ sub _choose_entry_for_category {
     my $default = $self->{default_adapter}{$category}
         || [ $self->_get_adapter_class("Null"), [] ];
     my ($adapter_class, $adapter_params) = @$default;
-    require_dynamic($adapter_class);
+    _require_dynamic($adapter_class);
     return {
         adapter_class  => $adapter_class,
         adapter_params => $adapter_params,
@@ -80,8 +77,10 @@ sub set {
     }
     my ( $adapter_name, @adapter_params ) = @_;
 
-    croak "expected adapter name"
-      unless defined($adapter_name) && $adapter_name =~ /\S/;
+    unless ( defined($adapter_name) && $adapter_name =~ /\S/ ) {
+        require Carp;
+        Carp::croak("expected adapter name");
+    }
 
     my $pattern = $options->{category};
     if ( !defined($pattern) ) {
@@ -92,7 +91,7 @@ sub set {
     }
 
     my $adapter_class = $self->_get_adapter_class($adapter_name);
-    require_dynamic($adapter_class);
+    _require_dynamic($adapter_class);
 
     my $entry = $self->_new_entry( $pattern, $adapter_class, \@adapter_params );
     unshift( @{ $self->{entries} }, $entry );
@@ -175,6 +174,18 @@ else {
       or die $@;
 }
 
+# XXX not DRY and not a great way to do this, but oh, well.
+sub _require_dynamic {
+    my ($class) = @_;
+
+    return 1 if $class->can('new'); # duck-type that class is loaded
+
+    unless ( defined( eval "require $class; 1" ) )
+    {    ## no critic (ProhibitStringyEval)
+        die $@;
+    }
+}
+
 package    # hide from PAUSE
   Log::Any::Manager::_Guard;
 
